@@ -45,7 +45,7 @@ impl PublicKey {
         }
     }
     /// Generate a Cosmos/Tendermint/Terrad Account
-    pub fn from_account(acc_address: &str) -> anyhow::Result<PublicKey> {
+    pub fn from_account(acc_address: &str) -> Result<PublicKey, TerraRustAPIError> {
         PublicKey::check_prefix_and_length("terra", acc_address, 44).and_then(|vu5| {
             let vu8 = Vec::from_base32(vu5.as_slice()).map_err(|source| {
                 TerraRustAPIError::Conversion {
@@ -60,7 +60,9 @@ impl PublicKey {
         })
     }
     /// build a public key from a tendermint public key
-    pub fn from_tendermint_key(tendermint_public_key: &str) -> anyhow::Result<PublicKey> {
+    pub fn from_tendermint_key(
+        tendermint_public_key: &str,
+    ) -> Result<PublicKey, TerraRustAPIError> {
         // Len 83 == PubKeySecp256k1 key with a prefix of 0xEB5AE987
         // Len 82 == PubKeyEd25519 key with a prefix of 0x1624DE64
 
@@ -84,7 +86,7 @@ impl PublicKey {
                             raw_address: Some(raw),
                         })
                     } else {
-                        Err(TerraRustAPIError::ConversionSECP256k1.into())
+                        Err(TerraRustAPIError::ConversionSECP256k1)
                     }
                 })
         } else if len == 82 {
@@ -110,18 +112,20 @@ impl PublicKey {
                         })
                     } else {
                         //     eprintln!("{}", hex::encode(&vu8));
-                        Err(TerraRustAPIError::ConversionED25519.into())
+                        Err(TerraRustAPIError::ConversionED25519)
                     }
                 })
 
             /* */
         } else {
-            Err(TerraRustAPIError::ConversionLength(len).into())
+            Err(TerraRustAPIError::ConversionLength(len))
         }
     }
     /// build a terravalcons address from a tendermint hex key
     /// the tendermint_hex_address should be a hex code of 40 length
-    pub fn from_tendermint_address(tendermint_hex_address: &str) -> anyhow::Result<PublicKey> {
+    pub fn from_tendermint_address(
+        tendermint_hex_address: &str,
+    ) -> Result<PublicKey, TerraRustAPIError> {
         let len = tendermint_hex_address.len();
         if len == 40 {
             let raw = hex::decode(tendermint_hex_address)?;
@@ -130,11 +134,11 @@ impl PublicKey {
                 raw_address: Some(raw),
             })
         } else {
-            Err(TerraRustAPIError::ConversionLengthED25519Hex(len).into())
+            Err(TerraRustAPIError::ConversionLengthED25519Hex(len))
         }
     }
     /// Generate a Operator address for this public key (used by the validator)
-    pub fn from_operator_address(valoper_address: &str) -> anyhow::Result<PublicKey> {
+    pub fn from_operator_address(valoper_address: &str) -> Result<PublicKey, TerraRustAPIError> {
         PublicKey::check_prefix_and_length("terravaloper", valoper_address, 51).and_then(|vu5| {
             let vu8 = Vec::from_base32(vu5.as_slice()).map_err(|source| {
                 TerraRustAPIError::Conversion {
@@ -150,7 +154,7 @@ impl PublicKey {
     }
 
     /// Generate Public key from raw address
-    pub fn from_raw_address(raw_address: &str) -> anyhow::Result<PublicKey> {
+    pub fn from_raw_address(raw_address: &str) -> Result<PublicKey, TerraRustAPIError> {
         let vec1 = hex::decode(raw_address)?;
 
         Ok(PublicKey {
@@ -158,7 +162,11 @@ impl PublicKey {
             raw_address: Some(vec1),
         })
     }
-    fn check_prefix_and_length(prefix: &str, data: &str, length: usize) -> anyhow::Result<Vec<u5>> {
+    fn check_prefix_and_length(
+        prefix: &str,
+        data: &str,
+        length: usize,
+    ) -> Result<Vec<u5>, TerraRustAPIError> {
         let (hrp, decoded_str, _) =
             decode(data).map_err(|source| TerraRustAPIError::Conversion {
                 key: data.into(),
@@ -167,10 +175,12 @@ impl PublicKey {
         if hrp == prefix && data.len() == length {
             Ok(decoded_str)
         } else {
-            Err(
-                TerraRustAPIError::Bech32DecodeExpanded(hrp, data.len(), prefix.into(), length)
-                    .into(),
-            )
+            Err(TerraRustAPIError::Bech32DecodeExpanded(
+                hrp,
+                data.len(),
+                prefix.into(),
+                length,
+            ))
         }
     }
     /**
@@ -198,7 +208,7 @@ impl PublicKey {
         .concat()
     }
     /// Translate from a BECH32 prefixed key to a standard public key
-    pub fn public_key_from_pubkey(pub_key: &[u8]) -> anyhow::Result<Vec<u8>> {
+    pub fn public_key_from_pubkey(pub_key: &[u8]) -> Result<Vec<u8>, TerraRustAPIError> {
         if pub_key.starts_with(&BECH32_PUBKEY_DATA_PREFIX_SECP256K1) {
             let len = BECH32_PUBKEY_DATA_PREFIX_SECP256K1.len();
             let len2 = pub_key.len();
@@ -211,7 +221,7 @@ impl PublicKey {
             Ok(ed25519_pubkey.to_bytes().to_vec())
         } else {
             log::info!("pub key does not start with BECH32 PREFIX");
-            Err(TerraRustAPIError::Bech32DecodeErr.into())
+            Err(TerraRustAPIError::Bech32DecodeErr)
         }
     }
 
@@ -243,15 +253,16 @@ impl PublicKey {
 
     */
 
-    pub fn address_from_public_ed25519_key(public_key: &[u8]) -> anyhow::Result<Vec<u8>> {
+    pub fn address_from_public_ed25519_key(
+        public_key: &[u8],
+    ) -> Result<Vec<u8>, TerraRustAPIError> {
         // Vec<bech32::u5> {
 
         if public_key.len() != (32 + 5/* the 5 is the BECH32 ED25519 prefix */) {
             Err(TerraRustAPIError::ConversionPrefixED25519(
                 public_key.len(),
                 hex::encode(public_key),
-            )
-            .into())
+            ))
         } else {
             // eprintln!("a_pub_ed_key {}", hex::encode(public_key));
             log::debug!(
@@ -282,75 +293,75 @@ impl PublicKey {
         }
     }
     /// The main account used in most things
-    pub fn account(&self) -> anyhow::Result<String> {
+    pub fn account(&self) -> Result<String, TerraRustAPIError> {
         match &self.raw_address {
             Some(raw) => {
                 let data = encode("terra", raw.to_base32(), Variant::Bech32);
                 match data {
                     Ok(acc) => Ok(acc),
-                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr.into()),
+                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr),
                 }
             }
-            None => Err(TerraRustAPIError::Implementation.into()),
+            None => Err(TerraRustAPIError::Implementation),
         }
     }
     /// The operator address used for validators
-    pub fn operator_address(&self) -> anyhow::Result<String> {
+    pub fn operator_address(&self) -> Result<String, TerraRustAPIError> {
         match &self.raw_address {
             Some(raw) => {
                 let data = encode("terravaloper", raw.to_base32(), Variant::Bech32);
                 match data {
                     Ok(acc) => Ok(acc),
-                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr.into()),
+                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr),
                 }
             }
-            None => Err(TerraRustAPIError::Implementation.into()),
+            None => Err(TerraRustAPIError::Implementation),
         }
     }
     /// application public key - Application keys are associated with a public key terrapub- and an address terra-
-    pub fn application_public_key(&self) -> anyhow::Result<String> {
+    pub fn application_public_key(&self) -> Result<String, TerraRustAPIError> {
         match &self.raw_pub_key {
             Some(raw) => {
                 let data = encode("terrapub", raw.to_base32(), Variant::Bech32);
                 match data {
                     Ok(acc) => Ok(acc),
-                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr.into()),
+                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr),
                 }
             }
             None => {
                 log::warn!("Missing Public Key. Can't continue");
-                Err(TerraRustAPIError::Implementation.into())
+                Err(TerraRustAPIError::Implementation)
             }
         }
     }
     /// The operator address used for validators public key.
-    pub fn operator_address_public_key(&self) -> anyhow::Result<String> {
+    pub fn operator_address_public_key(&self) -> Result<String, TerraRustAPIError> {
         match &self.raw_pub_key {
             Some(raw) => {
                 let data = encode("terravaloperpub", raw.to_base32(), Variant::Bech32);
                 match data {
                     Ok(acc) => Ok(acc),
-                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr.into()),
+                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr),
                 }
             }
-            None => Err(TerraRustAPIError::Implementation.into()),
+            None => Err(TerraRustAPIError::Implementation),
         }
     }
     /// This is a unique key used to sign block hashes. It is associated with a public key terravalconspub.
-    pub fn tendermint(&self) -> anyhow::Result<String> {
+    pub fn tendermint(&self) -> Result<String, TerraRustAPIError> {
         match &self.raw_address {
             Some(raw) => {
                 let data = encode("terravalcons", raw.to_base32(), Variant::Bech32);
                 match data {
                     Ok(acc) => Ok(acc),
-                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr.into()),
+                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr),
                 }
             }
-            None => Err(TerraRustAPIError::Implementation.into()),
+            None => Err(TerraRustAPIError::Implementation),
         }
     }
     /// This is a unique key used to sign block hashes. It is associated with a public key terravalconspub.
-    pub fn tendermint_pubkey(&self) -> anyhow::Result<String> {
+    pub fn tendermint_pubkey(&self) -> Result<String, TerraRustAPIError> {
         match &self.raw_pub_key {
             Some(raw) => {
                 // eprintln!("{} - tendermint_pubkey", hex::encode(raw));
@@ -358,10 +369,10 @@ impl PublicKey {
                 let data = encode("terravalconspub", b32, Variant::Bech32);
                 match data {
                     Ok(acc) => Ok(acc),
-                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr.into()),
+                    Err(_) => Err(TerraRustAPIError::Bech32DecodeErr),
                 }
             }
-            None => Err(TerraRustAPIError::Implementation.into()),
+            None => Err(TerraRustAPIError::Implementation),
         }
     }
 }
